import { VariantKey, StrictScreenshotOptions, ScreenshotOptions } from '../shared/types';
/**
 *
 * Convert to `viewport` and `variants` from `viewports` filed.
 *
 * @param options - Screenshot options which may have `viewports` field
 * @returns - Screenshot options with variants corresponding to the `viewports` field
 *
 **/
export declare function expandViewportsOption(options: ScreenshotOptions): ScreenshotOptions;
/**
 *
 * Returns fulfilled `ScreenshotOptions` object from some properties.
 *
 * @param props - Some properties of `ScreenshotOptions` fragment
 * @returns Fulfilled screenshot options
 *
 **/
export declare function createBaseScreenshotOptions({ delay, disableWaitAssets, viewports, }: {
    delay: number;
    disableWaitAssets: boolean;
    viewports: string[];
}): StrictScreenshotOptions;
/**
 *
 * Combines 2 screenshot options.
 *
 * @param base - The base screenshot options
 * @param fragment - The fragment screenshot options to override the base options
 * @returns Merged screenshot options
 *
 **/
export declare function mergeScreenshotOptions<T extends ScreenshotOptions>(base: T, fragment: ScreenshotOptions): T;
export type CircularVariantRef = {
    type: 'circular';
    refs: string[];
};
export type VariantKeyNotFound = {
    type: 'notFound';
    from: string;
    to: string;
};
export type InvalidVariantKeysReason = CircularVariantRef | VariantKeyNotFound;
/**
 *
 * Returns keys of all variants in given screenshot options expanding `extends` field in each variant.
 *
 * @param options - Screenshot options which may have `variants` field
 * @returns If succeeded extracted variant keys. If not succeeded the reason of the failure
 *
 **/
export declare function extractVariantKeys({ variants, defaultVariantSuffix, }: ScreenshotOptions): [InvalidVariantKeysReason | null, VariantKey[]];
/**
 *
 * Pick up screenshot options corresponding to given variant from the root screenshot options.
 *
 * @param options - The root(default) screenshot options
 * @param vk - Key of the target variant
 * @returns Screenshot options for the target variant
 *
 **/
export declare function pickupWithVariantKey(options: ScreenshotOptions, vk: VariantKey): ScreenshotOptions;
